# Copyright 2019 Google Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Timesketch API client library."""
from __future__ import unicode_literals

import json

import bs4

from . import definitions


def _get_message(response):
    """Return a formatted message string from the response text.

    Args:
        response (requests.Response): a response object from a HTTP
            request.

    Returns:
        str: a string with the message field extracted from the
            response.text.
    """
    soup = bs4.BeautifulSoup(response.text, features='html.parser')
    if soup.p:
        return soup.p.string

    if isinstance(response.text, bytes):
        response_text = response.text.decode('utf-8')
    else:
        response_text = response.text

    try:
        response_dict = json.loads(response_text)
    except json.JSONDecodeError:
        return response_text

    if not isinstance(response_dict, dict):
        return str(response_dict)

    return response_dict.get('message', str(response_dict))


def _get_reason(response):
    """Return the reason from a response.

    Args:
        response (requests.Response): a response object from a HTTP
            request.

    Returns:
        str: a string with the reason field extracted from the
            response.reason.
    """
    reason = response.reason
    if isinstance(reason, bytes):
        return reason.decode('utf-8')

    return reason


def get_response_json(response, logger):
    """Return the JSON object from a response, logging any errors.

    Args:
        response (requests.Response): a response object from a HTTP
            request.
        logger (logging.Logger): a logger object that can be used to
            write log messages.

    Returns:
        dict: a dict with the decoded JSON object within the HTTP
            response object.
    """
    status = response.status_code in definitions.HTTP_STATUS_CODE_20X
    if not status:
        reason = _get_reason(response)
        logger.warning('Failed response: [{0:d}] {2:s} {1:s}'.format(
            response.status_code, reason, _get_message(response)))

    try:
        return response.json()
    except json.JSONDecodeError as e:
        logger.error('Unable to decode response: {0!s}'.format(e))

    return {}


def error_message(response, message=None, error=RuntimeError):
    """Raise an error using error message extracted from response."""
    if not message:
        message = 'Unknown error, with error: '
    text = _get_message(response)

    raise error('{0:s}, with error [{1:d}] {2:s} {3:s}'.format(
        message, response.status_code, _get_reason(response), text))


def check_return_status(response, logger):
    """Check return status and return a boolean.

    Args:
        response (requests.Response): a response object from a HTTP
            request.
        logger (logging.Logger): a logger object that can be used to
            write log messages.

    Returns:
        bool: a boolean indicating whether the return status was in
            the 20X range of HTTP responses.
    """
    status = response.status_code in definitions.HTTP_STATUS_CODE_20X
    if status:
        return status

    logger.warning('Failed response: [{0:d}] {1:s}'.format(
        response.status_code, _get_message(response)))
    return status


class Error(Exception):
    """Base error class."""


class UnableToRunAnalyzer(Error):
    """Raised when unable to run an analyzer."""



# Copyright 2020 Google Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Tests for the Timesketch API client"""
import unittest
import mock

from . import client
from . import search
from . import test_lib


class SearchTest(unittest.TestCase):
    """Test Search object."""

    @mock.patch('requests.Session', test_lib.mock_session)
    def setUp(self):
        """Setup test case."""
        self.api_client = client.TimesketchApi(
            'http://127.0.0.1', 'test', 'test')
        self.sketch = self.api_client.get_sketch(1)

    def test_from_saved(self):
        """Test fetching object from store."""
        search_obj = search.Search(sketch=self.sketch)
        search_obj.from_saved(1)

        self.assertIsInstance(search_obj, search.Search)
        self.assertEqual(search_obj.id, 1)
        self.assertEqual(search_obj.name, 'test')
        query_filter = search_obj.query_filter

        self.assertEqual(query_filter.get('chips'), [])
        self.assertIsNone(query_filter.get('time_start', 'AA'))

    def test_from_manual(self):
        """Test fetching data."""
        search_obj = search.Search(sketch=self.sketch)
        search_obj.query_string = '*'
        df = search_obj.table
        self.assertEqual(len(df), 1)
        search_dict = search_obj.to_dict()
        meta = search_dict.get('meta', {})
        es_time = meta.get('es_time', 0)
        self.assertEqual(es_time, 12)

        objects = search_dict.get('objects', [])
        self.assertEqual(len(objects), 1)

    def test_range_chip(self):
        """Test date range chip."""
        chip = search.DateRangeChip()
        chip.start_time = '2020-11-30T12:12:12'
        chip.end_time = '2020-11-30T12:45:12'

        self.assertEqual(
            chip.date_range, '2020-11-30T12:12:12,2020-11-30T12:45:12')

        with self.assertRaises(ValueError):
            chip.start_time = '20bar'

        expected_chip = {
            'active': True,
            'field': '',
            'type': 'datetime_range',
            'operator': 'must',
            'value': '2020-11-30T12:12:12,2020-11-30T12:45:12',
        }
        self.assertEqual(chip.chip, expected_chip)

    def test_label_chip(self):
        """Test label chip."""
        chip = search.LabelChip()
        chip.label = 'foobar'

        expected_chip = {
            'active': True,
            'field': '',
            'type': 'label',
            'operator': 'must',
            'value': 'foobar'
        }
        self.assertEqual(chip.chip, expected_chip)

    def test_term_chip(self):
        """Test term chip."""
        chip = search.TermChip()
        chip.field = 'foobar'
        chip.query = '2fold'

        expected_chip = {
            'active': True,
            'field': 'foobar',
            'type': 'term',
            'operator': 'must',
            'value': '2fold'
        }
        self.assertEqual(chip.chip, expected_chip)

    def test_date_interval(self):
        """Test date interval chip."""
        chip = search.DateIntervalChip()
        with self.assertRaises(ValueError):
            chip.date = '20 minutes'

        date_string = '2020-11-30T12:12:12'
        chip.date = date_string

        expected_chip = {
            'active': True,
            'field': '',
            'type': 'datetime_interval',
            'operator': 'must',
            'value': f'{date_string} -5m +5m'
        }
        self.assertEqual(chip.chip, expected_chip)

        chip.unit = 'h'
        chip.before = 1
        chip.after = 6
        expected_chip['value'] = f'{date_string} -1h +6h'

        self.assertEqual(chip.chip, expected_chip)



# Copyright 2019 Google Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Timesketch API client library."""
from __future__ import unicode_literals

import json
import logging

from . import error
from . import resource


logger = logging.getLogger('timesketch_api.index')


class SearchIndex(resource.BaseResource):
    """Timesketch searchindex object.

    Attributes:
        id: The ID of the search index.
        api: An instance of TimesketchApi object.
    """

    def __init__(self, searchindex_id, api, searchindex_name=None):
        """Initializes the SearchIndex object.

        Args:
            searchindex_id: Primary key ID of the searchindex.
            searchindex_name: Name of the searchindex (optional).
        """
        self.id = searchindex_id
        self._labels = []
        self._searchindex_name = searchindex_name
        self._resource_uri = 'searchindices/{0:d}'.format(self.id)
        super().__init__(
            api=api, resource_uri=self._resource_uri)

    def _get_object_dict(self):
        """Returns the object dict from the resources dict."""
        data = self.lazyload_data()
        objects = data.get('objects', [])
        if not objects:
            return {}

        return objects[0]

    @property
    def labels(self):
        """Property that returns the SearchIndex labels."""
        if self._labels:
            return self._labels

        index_data = self._get_object_dict()
        if not index_data:
            return self._labels

        label_string = index_data.get('label_string', '')
        if label_string:
            self._labels = json.loads(label_string)
        else:
            self._labels = []

        return self._labels

    @property
    def name(self):
        """Property that returns searchindex name.

        Returns:
            Searchindex name as string.
        """
        if not self._searchindex_name:
            index_data = self._get_object_dict()
            self._searchindex_name = index_data.get('name', 'no name defined')
        return self._searchindex_name

    @property
    def index_name(self):
        """Property that returns Elasticsearch index name.

        Returns:
            Elasticsearch index name as string.
        """
        index_data = self._get_object_dict()
        return index_data.get('index_name', 'unkown index name')

    @property
    def status(self):
        """Property that returns the index status.

        Returns:
            String with the index status.
        """
        index_data = self._get_object_dict()
        status_list = index_data.get('status')
        if not status_list:
            return 'Unknown'

        status = status_list[0]
        return status.get('status')

    @property
    def description(self):
        """Property that returns the description of the index."""
        index_data = self._get_object_dict()
        return index_data.get('description', 'no description provided')

    def delete(self):
        """Deletes the index."""
        resource_url = '{0:s}/searchindices/{1:d}/'.format(
            self.api.api_root, self.id)
        response = self.api.session.delete(resource_url)
        return error.check_return_status(response, logger)



# Copyright 2020 Google Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Tests for the Timesketch API client"""
import unittest
import mock

from . import client
from . import graph
from . import test_lib


class GraphTest(unittest.TestCase):
    """Test Graph object."""

    @mock.patch('requests.Session', test_lib.mock_session)
    def setUp(self):
        """Setup test case."""
        self.api_client = client.TimesketchApi(
            'http://127.0.0.1', 'test', 'test')
        self.sketch = self.api_client.get_sketch(1)

    def test_from_manual(self):
        """Test setting up a graph from manual."""
        data = {
          0: {
            1: {'weight': 1}
          }
        }
        graph_obj = graph.Graph(self.sketch)
        graph_obj.from_manual(data)
        self.assertEqual(graph_obj.graph.size(), 1)



# Copyright 2020 Google Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Tests for the Timesketch API client"""
from __future__ import unicode_literals

import unittest
import mock

from . import client
from . import test_lib
from . import story as story_lib


class StoryTest(unittest.TestCase):
    """Test Story object."""

    @mock.patch('requests.Session', test_lib.mock_session)
    def setUp(self):
        """Setup test case."""
        self.api_client = client.TimesketchApi(
            'http://127.0.0.1', 'test', 'test')
        self.sketch = self.api_client.get_sketch(1)

    def test_story(self):
        """Test story object."""
        story = self.sketch.list_stories()[0]
        self.assertIsInstance(story, story_lib.Story)
        self.assertEqual(story.id, 1)
        self.assertEqual(story.title, 'My First Story')
        self.assertEqual(len(story), 3)
        blocks = list(story.blocks)
        text_count = 0
        view_count = 0
        for block in blocks:
            if block.TYPE == 'text':
                text_count += 1
            elif block.TYPE == 'view':
                view_count += 1

        self.assertEqual(text_count, 2)
        self.assertEqual(view_count, 1)

        self.assertEqual(blocks[0].text, '# My Heading\nWith Some Text.')

        blocks[0].move_down()
        blocks = list(story.blocks)
        self.assertEqual(len(blocks), 3)
        self.assertEqual(blocks[1].text, '# My Heading\nWith Some Text.')



# Copyright 2020 Google Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Timesketch API analyzer result object."""
from __future__ import unicode_literals

import datetime
import json
import logging

from . import error
from . import resource


logger = logging.getLogger('timesketch_api.analyzer')


class AnalyzerResult(resource.BaseResource):
    """Class to store and retrieve session information for an analyzer."""

    def __init__(self, timeline_id, session_id, sketch_id, api):
        """Initialize the class."""
        self._session_id = session_id
        self._sketch_id = sketch_id
        self._timeline_id = timeline_id
        resource_uri = (
            '{0:s}/sketches/{1:d}/timelines/{2:d}/analysis/').format(
                api.api_root, sketch_id, timeline_id)
        super().__init__(api, resource_uri)

    def _fetch_data(self):
        """Returns a dict with the analyzer results."""
        response = self.api.session.get(self.resource_uri)
        if not error.check_return_status(response, logger):
            return {}

        data = error.get_response_json(response, logger)

        objects = data.get('objects')
        if not objects:
            return {}

        result_dict = {}
        for result in objects[0]:
            result_id = result.get('analysissession_id')
            if result_id != self._session_id:
                continue
            status_list = result.get('status', [])
            if len(status_list) != 1:
                continue
            status = status_list[0]

            timeline = result.get('timeline', {})

            result_dict['id'] = result_id
            result_dict.setdefault('analyzers', [])
            result_dict['analyzers'].append({
                'name': result.get('analyzer_name', 'N/A'),
                'results': result.get('result'),
                'description': result.get('description', 'N/A'),
                'user': result.get('user', {}).get('username', 'System'),
                'parameters': json.loads(result.get('parameters', '{}')),
                'status': status.get('status', 'Unknown'),
                'status_date': status.get('updated_at', ''),
                'log': result.get('log', ''),
                'created': result.get('created_at'),
                'timeline': timeline.get('name', 'N/A'),
                'timeline_id': timeline.get('id', -1),
                'timeline_user': timeline.get('user', {}).get(
                    'username', 'System'),
                'timeline_name': timeline.get('name', 'N/A'),
                'timeline_deleted': timeline.get('deleted', False),
            })

        return result_dict

    @property
    def id(self):
        """Returns the session ID."""
        return self._session_id

    @property
    def log(self):
        """Returns back logs from the analyzer session, if there are any."""
        data = self._fetch_data()
        return_strings = []
        for entry in data.get('analyzers', []):
            return_strings.append(
                '[{0:s}] = {1:s}'.format(
                    entry.get('name', 'No Name'),
                    entry.get('log', 'No recorded logs.')))
        return '\n'.join(return_strings)

    @property
    def results(self):
        """Returns the results from the analyzer session."""
        data = self._fetch_data()
        return_strings = []
        for entry in data.get('analyzers', []):
            results = entry.get('results')
            if not results:
                results = 'No results yet.'
            return_strings.append(
                '[{0:s}] = {1:s}'.format(
                    entry.get('name', 'No Name'), results))
        return '\n'.join(return_strings)

    @property
    def status(self):
        """Returns the current status of the analyzer run."""
        data = self._fetch_data()
        return_strings = []
        for entry in data.get('analyzers', []):
            return_strings.append(
                '[{0:s}] = {1:s}'.format(
                    entry.get('name', 'No Name'),
                    entry.get('status', 'Unknown.')))
        return '\n'.join(return_strings)

    @property
    def status_string(self):
        """Returns a longer version of a status string."""
        data = self._fetch_data()
        return_strings = []
        for entry in data.get('analyzers', []):
            return_strings.append(
                '{0:s} - {1:s}: {2:s}'.format(
                    entry.get('name', 'No Name'),
                    entry.get(
                        'status_date', datetime.datetime.utcnow().isoformat()),
                    entry.get('status', 'Unknown.')))
        return '\n'.join(return_strings)



# Copyright 2019 Google Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Timesketch API client library."""
from __future__ import unicode_literals

import json
import logging

from . import resource


logger = logging.getLogger('timesketch_api.view')


class View(resource.BaseResource):
    """Saved view object.

    Attributes:
        id: Primary key of the view.
        name: Name of the view.
    """

    def __init__(self, view_id, view_name, sketch_id, api):
        """Initializes the View object.

        Args:
            view_id: Primary key ID for the view.
            view_name: The name of the view.
            sketch_id: ID of a sketch.
            api: Instance of a TimesketchApi object.
        """
        logger.info(
            'View objects will be deprecated soon, consider transitioning '
            'into using the search.Search object instead')
        self.id = view_id
        self.name = view_name
        resource_uri = 'sketches/{0:d}/views/{1:d}/'.format(sketch_id, self.id)
        super().__init__(api, resource_uri)

    def _get_top_level_attribute(self, name, default_value=None, refresh=False):
        """Returns a top level attribute from a view object.

        Args:
            name: String with the attribute name.
            default_value: The default value if the attribute does not exit,
                defaults to None.
            refresh: If set to True then the data will be refreshed.

        Returns:
            The dict value of the key "name".
        """
        view = self.lazyload_data(refresh_cache=refresh)
        view_objects = view.get('objects')
        if not view_objects:
            return default_value
        if not len(view_objects) == 1:
            return default_value

        first_object = view_objects[0]
        return first_object.get(name, default_value)

    @property
    def description(self):
        """Property that returns the description value of a view.

        Returns:
            Description of the view as a string.
        """
        return self._get_top_level_attribute('description', default_value='')

    @property
    def user(self):
        """Property that returns the username of the view creator.

        Returns:
            A string with the username of the user generating the view.
        """
        user_dict = self._get_top_level_attribute('user', default_value={})
        username = user_dict.get('username')
        if not username:
            return 'System'
        return username

    @property
    def query_string(self):
        """Property that returns the views query string.

        Returns:
            Elasticsearch query as string.
        """
        return self._get_top_level_attribute('query_string', default_value='')

    @property
    def query_filter(self):
        """Property that returns the views filter.

        Returns:
            Elasticsearch filter as a dict.
        """
        query_filter_string = self._get_top_level_attribute(
            'query_filter', default_value='')
        if not query_filter_string:
            return ''
        return json.loads(query_filter_string)

    @property
    def query_dsl(self):
        """Property that returns the views query DSL.

        Returns:
            Elasticsearch DSL as a dict.
        """
        dsl_string = self._get_top_level_attribute(
            'query_dsl', default_value='')
        if not dsl_string:
            return ''
        return json.loads(dsl_string)



# Copyright 2020 Google Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Tests for the Timesketch API client"""
from __future__ import unicode_literals

import unittest
import mock

from . import test_lib
from . import client


class TimesketchSigmaTest(unittest.TestCase):
    """Test Sigma."""

    @mock.patch('requests.Session', test_lib.mock_session)
    def setUp(self):
        """Setup test case."""
        self.api_client = client.TimesketchApi(
            'http://127.0.0.1', 'test', 'test')

    def test_sigma_rule(self):
        """Test single Sigma rule."""

        rule = self.api_client.get_sigma_rule(
            '5266a592-b793-11ea-b3de-0242ac130004')

        self.assertIsNotNone(rule)

        self.assertEqual(
            rule.title, 'Suspicious Installation of Zenmap',
            'Title of the rule does not match')
        self.assertEqual(
            rule.id, '5266a592-b793-11ea-b3de-0242ac130004',
            'Id of the rule does not match')

    def test_sigma_rules(self):
        '''Testing the Sigma rules list'''

        rules = self.api_client.list_sigma_rules()
        self.assertIsNotNone(rules)

        rule1 = rules[0]

        self.assertEqual(
            rule1.title, 'Suspicious Installation of Zenmap',
            'Title of the rule does not match')



# Copyright 2020 Google Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Timesketch API sigma library."""
from __future__ import unicode_literals

import logging

from . import resource

logger = logging.getLogger('timesketch_api.sigma')


class Sigma(resource.BaseResource):
    """Timesketch sigma object.

    A sigma object in Timesketch is a collection of one or more rules.

    Attributes:
        rule_uuid: The ID of the rule.
    """


    def __init__(self, rule_uuid, api, es_query=None,
                 file_name=None, title=None, description=None,
                 file_relpath=None):
        """Initializes the Sigma object.

        Args:
            rule_uuid: Id of the sigma rule.
            api: An instance of TimesketchApi object.
            es_query: Elastic Search query of the rule
            file_name: File name of the rule
            title: Title of the rule
            description: Description of the rule
            file_relpath: path of the file relative to the config value

        """
        self.rule_uuid = rule_uuid
        self._description = description
        self._es_query = es_query
        self._file_name = file_name
        self._title = title
        self._file_relpath = file_relpath
        self._resource_uri = f'sigma/{self.rule_uuid}'
        super().__init__(
            api=api, resource_uri=self._resource_uri)

    @property
    def es_query(self):
        """Returns the elastic search query."""
        sigma_data = self.data

        if not sigma_data:
            return ''

        return sigma_data.get('es_query', '')

    @property
    def title(self):
        """Returns the sigma rule title."""
        sigma_data = self.data

        if not sigma_data:
            return ''

        return sigma_data.get('title', '')

    @property
    def id(self):
        """Returns the sigma rule id."""
        sigma_data = self.data

        if not sigma_data:
            return ''

        return sigma_data.get('id', '')

    @property
    def file_relpath(self):
        """Returns the relative filepath of the rule."""
        sigma_data = self.data

        if not sigma_data:
            return ''

        return sigma_data.get('file_relpath', '')



#!/usr/bin/env python
# Copyright 2017 Google Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""This is the setup file for the project."""
from __future__ import unicode_literals

from setuptools import find_packages
from setuptools import setup

from timesketch_api_client import version


long_description = (
    'The Timesketch API client provides you with a set of Python libraries '
    'to connect to your Timesketch (https://github.com/google/timesketch) '
    'instance.\n\n'
    'The API is feature complete with the Timesketch UI and allows you to '
    'do all operations that can be done in the UI, providing ways to '
    'integrate Timesketch into other products such as Jupyter/Colab.\n\n'
    'To see how it works in action, try the colab notebook that is accessible '
    'from here: https://colab.research.google.com/github/google/timesketch/'
    'blob/master/notebooks/colab-timesketch-demo.ipynb')


setup(
    name='timesketch-api-client',
    version=version.get_version(),
    description='Timesketch API client',
    long_description=long_description,
    license='Apache License, Version 2.0',
    url='http://www.timesketch.org/',
    maintainer='Timesketch development team',
    maintainer_email='timesketch-dev@googlegroups.com',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ],
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    install_requires=frozenset([
        'pandas',
        'cryptography',
        'requests',
        'altair',
        'google-auth',
        'networkx',
        'google_auth_oauthlib',
        'beautifulsoup4']),
    )
